@@ -1,6 +1,6 @@
 use std::{future::Future, mem::take, sync::Arc, time::Instant};
 
-use process_wrap::tokio::TokioCommandWrap;
+use process_wrap::tokio::CommandWrap;
 use tokio::{select, task::JoinHandle};
 use tracing::{instrument, trace, trace_span, Instrument};
 use watchexec_signals::Signal;
@@ -65,7 +65,9 @@ pub fn start_job(command: Arc<Command>) -> (Job, JoinHandle<()>) {
 								}
 								Ok(true) => {
 									trace!(existing=?stop_timer, "erasing stop timer");
-									stop_timer = None;
+									if let Some(timer) = stop_timer.take() {
+										timer.done.raise();
+									}
 									trace!(count=%on_end.len(), "raising all pending end flags");
 									for done in take(&mut on_end) {
 										done.raise();
@@ -159,7 +161,7 @@ pub fn start_job(command: Arc<Command>) -> (Job, JoinHandle<()>) {
 										trace!("stopping child");
 										try_with_handler!(Box::into_pin(child.kill()).await);
 										trace!("waiting on child");
-										let status = try_with_handler!(Box::into_pin(child.wait()).await);
+										let status = try_with_handler!(child.wait().await);
 
 										trace!(?status, "got child end status");
 										command_state = CommandState::Finished {
@@ -191,7 +193,7 @@ pub fn start_job(command: Arc<Command>) -> (Job, JoinHandle<()>) {
 										trace!("stopping child");
 										try_with_handler!(Box::into_pin(child.kill()).await);
 										trace!("waiting on child");
-										let status = try_with_handler!(Box::into_pin(child.wait()).await);
+										let status = try_with_handler!(child.wait().await);
 
 										trace!(?status, "got child end status");
 										command_state = CommandState::Finished {
@@ -241,7 +243,7 @@ pub fn start_job(command: Arc<Command>) -> (Job, JoinHandle<()>) {
 										trace!("stopping child forcefully");
 										try_with_handler!(Box::into_pin(child.kill()).await);
 										trace!("waiting on child");
-										let status = try_with_handler!(Box::into_pin(child.wait()).await);
+										let status = try_with_handler!(child.wait().await);
 
 										trace!(?status, "got child end status");
 										command_state = CommandState::Finished {
@@ -352,6 +354,10 @@ pub fn start_job(command: Arc<Command>) -> (Job, JoinHandle<()>) {
 						}
 					}
 				}
+				else => {
+					trace!("all select branches disabled, exiting");
+					break 'main;
+				}
 				}
 			}
 
@@ -411,16 +417,15 @@ pub type AsyncFunc = Box<
 		+ 'static,
 >;
 
-pub type SyncSpawnHook =
-	Arc<dyn Fn(&mut TokioCommandWrap, &JobTaskContext<'_>) + Send + Sync + 'static>;
+pub type SyncSpawnHook = Arc<dyn Fn(&mut CommandWrap, &JobTaskContext<'_>) + Send + Sync + 'static>;
 pub type AsyncSpawnHook = Arc<
-	dyn (Fn(&mut TokioCommandWrap, &JobTaskContext<'_>) -> Box<dyn Future<Output = ()> + Send + Sync>)
+	dyn (Fn(&mut CommandWrap, &JobTaskContext<'_>) -> Box<dyn Future<Output = ()> + Send + Sync>)
 		+ Send
 		+ Sync
 		+ 'static,
 >;
 
-sync_async_callbox!(SpawnHook, SyncSpawnHook, AsyncSpawnHook, (command: &mut TokioCommandWrap, context: &JobTaskContext<'_>));
+sync_async_callbox!(SpawnHook, SyncSpawnHook, AsyncSpawnHook, (command: &mut CommandWrap, context: &JobTaskContext<'_>));
 
 pub type SyncErrorHandler = Arc<dyn Fn(SyncIoError) + Send + Sync + 'static>;
 pub type AsyncErrorHandler = Arc<
@@ -433,7 +438,7 @@ sync_async_callbox!(ErrorHandler, SyncErrorHandler, AsyncErrorHandler, (error: S
 #[instrument(level = "trace")]
 async fn signal_child(
 	signal: Signal,
-	#[cfg(not(test))] child: &mut Box<dyn process_wrap::tokio::TokioChildWrapper>,
+	#[cfg(not(test))] child: &mut Box<dyn process_wrap::tokio::ChildWrapper>,
 	#[cfg(test)] child: &mut super::TestChild,
 ) -> std::io::Result<()> {
 	#[cfg(unix)]
